package java.sql;

import java.net.URL;
import java.util.Calendar;
import java.io.Reader;
import java.io.InputStream;
import java.math.BigDecimal;

public interface PreparedStatement extends Statement
{
    public abstract ResultSet executeQuery() throws SQLException;
    
    public abstract int executeUpdate() throws SQLException;
    
    public abstract void setNull(int p0, int p1) throws SQLException;
    
    public abstract void setBoolean(int p0, boolean p1) throws SQLException;
    
    public abstract void setByte(int p0, byte p1) throws SQLException;
    
    public abstract void setShort(int p0, short p1) throws SQLException;
    
    public abstract void setInt(int p0, int p1) throws SQLException;
    
    public abstract void setLong(int p0, long p1) throws SQLException;
    
    public abstract void setFloat(int p0, float p1) throws SQLException;
    
    public abstract void setDouble(int p0, double p1) throws SQLException;
    
    public abstract void setBigDecimal(int p0, BigDecimal p1) throws SQLException;
    
    public abstract void setString(int p0, String p1) throws SQLException;
    
    public abstract void setBytes(int p0, byte[] p1) throws SQLException;
    
    public abstract void setDate(int p0, Date p1) throws SQLException;
    
    public abstract void setTime(int p0, Time p1) throws SQLException;
    
    public abstract void setTimestamp(int p0, Timestamp p1) throws SQLException;
    
    public abstract void setAsciiStream(int p0, InputStream p1, int p2) throws SQLException;
    
    @Deprecated
    public abstract void setUnicodeStream(int p0, InputStream p1, int p2) throws SQLException;
    
    public abstract void setBinaryStream(int p0, InputStream p1, int p2) throws SQLException;
    
    public abstract void clearParameters() throws SQLException;
    
    public abstract void setObject(int p0, Object p1, int p2) throws SQLException;
    
    public abstract void setObject(int p0, Object p1) throws SQLException;
    
    public abstract boolean execute() throws SQLException;
    
    public abstract void addBatch() throws SQLException;
    
    public abstract void setCharacterStream(int p0, Reader p1, int p2) throws SQLException;
    
    public abstract void setRef(int p0, Ref p1) throws SQLException;
    
    public abstract void setBlob(int p0, Blob p1) throws SQLException;
    
    public abstract void setClob(int p0, Clob p1) throws SQLException;
    
    public abstract void setArray(int p0, Array p1) throws SQLException;
    
    public abstract ResultSetMetaData getMetaData() throws SQLException;
    
    public abstract void setDate(int p0, Date p1, Calendar p2) throws SQLException;
    
    public abstract void setTime(int p0, Time p1, Calendar p2) throws SQLException;
    
    public abstract void setTimestamp(int p0, Timestamp p1, Calendar p2) throws SQLException;
    
    public abstract void setNull(int p0, int p1, String p2) throws SQLException;
    
    public abstract void setURL(int p0, URL p1) throws SQLException;
    
    public abstract ParameterMetaData getParameterMetaData() throws SQLException;
    
    public abstract void setRowId(int p0, RowId p1) throws SQLException;
    
    public abstract void setNString(int p0, String p1) throws SQLException;
    
    public abstract void setNCharacterStream(int p0, Reader p1, long p2) throws SQLException;
    
    public abstract void setNClob(int p0, NClob p1) throws SQLException;
    
    public abstract void setClob(int p0, Reader p1, long p2) throws SQLException;
    
    public abstract void setBlob(int p0, InputStream p1, long p2) throws SQLException;
    
    public abstract void setNClob(int p0, Reader p1, long p2) throws SQLException;
    
    public abstract void setSQLXML(int p0, SQLXML p1) throws SQLException;
    
    public abstract void setObject(int p0, Object p1, int p2, int p3) throws SQLException;
    
    public abstract void setAsciiStream(int p0, InputStream p1, long p2) throws SQLException;
    
    public abstract void setBinaryStream(int p0, InputStream p1, long p2) throws SQLException;
    
    public abstract void setCharacterStream(int p0, Reader p1, long p2) throws SQLException;
    
    public abstract void setAsciiStream(int p0, InputStream p1) throws SQLException;
    
    public abstract void setBinaryStream(int p0, InputStream p1) throws SQLException;
    
    public abstract void setCharacterStream(int p0, Reader p1) throws SQLException;
    
    public abstract void setNCharacterStream(int p0, Reader p1) throws SQLException;
    
    public abstract void setClob(int p0, Reader p1) throws SQLException;
    
    public abstract void setBlob(int p0, InputStream p1) throws SQLException;
    
    public abstract void setNClob(int p0, Reader p1) throws SQLException;
    
    default public void setObject(int n, Object o, SQLType sqlType, int n2) throws SQLException {
        throw new SQLFeatureNotSupportedException("setObject not implemented");
    }
    
    default public void setObject(int n, Object o, SQLType sqlType) throws SQLException {
        throw new SQLFeatureNotSupportedException("setObject not implemented");
    }
    
    default public long executeLargeUpdate() throws SQLException {
        throw new UnsupportedOperationException("executeLargeUpdate not implemented");
    }
}
